@@ -2,22 +2,30 @@
 # -*- coding: utf-8 -*-
 
 # Fenrir TTY screen reader
-# By Chrys, Storm Dragon, and contributers.
+# By Chrys, Storm Dragon, and contributors.
 
-from fenrirscreenreader.core import debug
 
-class command():
+from fenrirscreenreader.core.i18n import _
+
+
+class command:
     def __init__(self):
         pass
+
     def initialize(self, environment):
         self.env = environment
+
     def shutdown(self):
         pass
-    def getDescription(self):
-        return 'No description found'         
+
+    def get_description(self):
+        return "No description found"
+
     def unload(self):
         pass
+
     def load(self):
         pass
-    def setCallback(self, callback):
+
+    def set_callback(self, callback):
         pass
