@@ -2,12 +2,15 @@
 
 from enum import Enum
 
-class debugLevel(Enum):
+
+class DebugLevel(Enum):
     DEACTIVE = 0
     ERROR = 1
     WARNING = 2
     INFO = 3
+
     def __int__(self):
         return self.value
+
     def __str__(self):
         return self.name
