@@ -2,15 +2,18 @@
 # -*- coding: utf-8 -*-
 
 # Fenrir TTY screen reader
-# By Chrys, Storm Dragon, and contributers.
+# By Chrys, Storm Dragon, and contributors.
 
 from fenrirscreenreader.core import debug
 
-class remoteDriver():
+
+class RemoteDriver:
     def __init__(self):
-        self._isInitialized = False
+        self._is_initialized = False
+
     def initialize(self, environment):
         self.env = environment
-        self._isInitialized = True
+        self._is_initialized = True
+
     def shutdown(self):
-        self._isInitialized = False
+        self._is_initialized = False
