@@ -2,29 +2,39 @@
 # -*- coding: utf-8 -*-
 
 # Fenrir TTY screen reader
-# By Chrys, Storm Dragon, and contributers.
+# By Chrys, Storm Dragon, and contributors.
 
 from fenrirscreenreader.core import debug
 
-class sayAllManager():
+
+class SayAllManager:
     def __init__(self):
         self.isActive = False
         self.isActiveLock = None
+
     def initialize(self, environment):
-        self.env = environment  
+        self.env = environment
+
     def shutdown(self):
         pass
-    def setIsActive(self, isActive):
+
+    def set_is_active(self, isActive):
         pass
+
     def start(self):
         pass
-    def isSayAllActive(self):
+
+    def is_say_all_active(self):
         pass
-    def sayAllWorker(self):
+
+    def say_all_worker(self):
         pass
+
     def stop(self):
         pass
+
     def finish(self):
         pass
-    def gotoNextPage(self):
+
+    def goto_next_page(self):
         pass
