@@ -2,11 +2,12 @@
 # -*- coding: utf-8 -*-
 
 # Fenrir TTY screen reader
-# By Chrys, Storm Dragon, and contributers.
+# By Chrys, Storm Dragon, and contributors.
 
 from fenrirscreenreader.core import debug
 
-class soundDriver():
+
+class sound_driver:
     def __init__(self):
         self.volume = None
         self._initialized = False
@@ -19,15 +20,17 @@ class soundDriver():
         if not self._initialized:
             return
         self.cancel()
-        self._isInitialized = False
+        self._is_initialized = False
 
-    def playFrequence(self, frequence, duration, adjustVolume = 0.0, interrupt=True):
+    def play_frequence(
+        self, frequence, duration, adjust_volume=0.0, interrupt=True
+    ):
         if not self._initialized:
             return
         if interrupt:
             self.cancel()
 
-    def playSoundFile(self, filePath, interrupt = True):
+    def play_sound_file(self, file_path, interrupt=True):
         if not self._initialized:
             return
         if interrupt:
@@ -37,11 +40,11 @@ class soundDriver():
         if not self._initialized:
             return
 
-    def setCallback(self, callback):
+    def set_callback(self, callback):
         if not self._initialized:
             return
 
-    def setVolume(self, volume):
+    def set_volume(self, volume):
         if not self._initialized:
             return
         self.volume = volume
