@@ -2,11 +2,13 @@
 # -*- coding: utf-8 -*-
 
 # Fenrir TTY screen reader
-# By Chrys, Storm Dragon, and contributers.
+# By Chrys, Storm Dragon, and contributors.
 
 import time
+
 from fenrirscreenreader.core import debug
-from fenrirscreenreader.core.inputDriver import inputDriver
+from fenrirscreenreader.core.inputDriver import InputDriver as inputDriver
+
 
 class driver(inputDriver):
     def __init__(self):
