@@ -2,10 +2,11 @@
 # -*- coding: utf-8 -*-
 
 # Fenrir TTY screen reader
-# By Chrys, Storm Dragon, and contributers.
+# By Chrys, Storm Dragon, and contributors.
 
 from fenrirscreenreader.core import debug
-from fenrirscreenreader.core.remoteDriver import remoteDriver
+from fenrirscreenreader.core.remoteDriver import RemoteDriver as remoteDriver
+
 
 class driver(remoteDriver):
     def __init__(self):
