@@ -2,10 +2,11 @@
 # -*- coding: utf-8 -*-
 
 # Fenrir TTY screen reader
-# By Chrys, Storm Dragon, and contributers.
+# By Chrys, Storm Dragon, and contributors.
 
 from fenrirscreenreader.core import debug
-from fenrirscreenreader.core.screenDriver import screenDriver
+from fenrirscreenreader.core.screenDriver import ScreenDriver as screenDriver
+
 
 class driver(screenDriver):
     def __init__(self):
